# Colorbrewer
Constants from Cynthia Brewer's ColorBrewer

An easy way to get access to ColorBrewer schemes from within a Python program

## Author
Michael Hoffman michael.hoffman AT @ utoronto.ca


## Installation
### From PyPI
pip install colorbrewer

### From source
pip install .

## License
ColorBrewer is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.
